import { StoreApi } from 'zustand';
import { FilterValue, FilterMap, CategoryValue } from './types';
import { DateCell } from './components/cells/date';
import { TimeCell } from './components/cells/time';
import { NumberCell } from './components/cells/number';
import { RawNumberCell } from './components/cells/raw-number';
import { StringCell } from './components/cells/string';
import { ColorCell } from './components/cells/color';
import { CategoryCell } from './components/cells/category';
import { StringFilter } from './components/filters/string';
import { CategoryFilter } from './components/filters/category';
import { RangeFilter } from './components/filters/range';
export declare type GridState = {
    data: any[];
    rawData: any[];
    updatedData: any[] | null;
    stickyColumnName?: string;
    handleStickyColumnNameChange: (columnName: string) => void;
    columnNames: string[];
    filteredData: any[];
    diffs: object[];
    uniqueColumnName?: string;
    filters: FilterMap<FilterValue>;
    metadata: Record<string, string>;
    handleMetadataChange: (metadata: Record<string, string>) => void;
    handleFilterChange: (column: string, value: FilterValue) => void;
    handleFiltersChange: (newFilters?: FilterMap<FilterValue>) => void;
    handleDataChange: (data: any[]) => void;
    handleDiffDataChange: (data: any[]) => void;
    categoryValues: Record<string, CategoryValue[]>;
    sort: string[];
    handleSortChange: (columnName: string, direction: string) => void;
    focusedRowIndex?: number;
    handleFocusedRowIndexChange: (rowIndex?: number) => void;
    schema?: object;
    cellTypes: Record<string, string>;
    columnWidths: number[];
    updateColumnWidths: () => void;
    updateColumnNames: () => void;
    updateFilteredColumns: () => void;
    isEditable: boolean;
    handleIsEditableChange: (isEditable: boolean) => void;
    onCellChange: (rowIndex: number, columnName: string, value: any) => void;
    onRowDelete: (rowIndex: number) => void;
    onHeaderCellChange: (oldColumnName: string, newColumnName: any) => void;
    onHeaderAdd: (columnName: string) => void;
    onHeaderDelete: (columnName: string) => void;
    focusedCellPosition: [number, number] | null;
    handleFocusedCellPositionChange: (position: [number, number] | null) => void;
};
export declare const originalRowIndexColumnName = "__originalIndex__";
export declare const createGridStore: () => import("zustand").UseBoundStore<GridState, StoreApi<GridState>>;
export declare const cellTypeMap: {
    string: {
        cell: typeof StringCell;
        filter: typeof StringFilter;
        format: (d: string) => string;
        shortFormat: (d: string) => string;
        sortValueType: string;
    };
    color: {
        cell: typeof ColorCell;
        filter: typeof StringFilter;
        format: (d: string) => string;
        shortFormat: (d: string) => string;
        sortValueType: string;
    };
    object: {
        cell: typeof StringCell;
        filter: typeof StringFilter;
        format: (d: string) => string;
        shortFormat: (d: string) => string;
        parseValueFunction: (d: any[]) => string;
        sortValueType: string;
    };
    array: {
        cell: typeof StringCell;
        filter: typeof StringFilter;
        format: (d: string) => string;
        shortFormat: (d: string) => string;
        parseValueFunction: (d: any[]) => string;
        sortValueType: string;
    };
    'short-array': {
        cell: typeof StringCell;
        filter: typeof StringFilter;
        format: (d: string) => string;
        shortFormat: (d: string) => string;
        parseValueFunction: (d: [string]) => string;
        sortValueType: string;
    };
    category: {
        cell: typeof CategoryCell;
        filter: typeof CategoryFilter;
        format: (d: string) => string;
        shortFormat: (d: string) => string;
        parseValueFunction: (d: [string]) => [string];
        sortValueType: string;
        extraCellHorizontalPadding: number;
    };
    number: {
        cell: typeof NumberCell;
        filter: typeof RangeFilter;
        format: (d: number) => string;
        shortFormat: (d: number) => string;
        parseValueFunction: (d: any[]) => number | undefined;
        minWidth: number;
        hasScale: boolean;
        sortValueType: string;
    };
    year: {
        cell: typeof RawNumberCell;
        filter: typeof RangeFilter;
        format: (d: number) => string;
        shortFormat: (d: number) => number;
        parseValueFunction: (d: any[]) => number;
        minWidth: number;
        hasScale: boolean;
        sortValueType: string;
    };
    'short-range-date': {
        cell: typeof DateCell;
        filter: typeof RangeFilter;
        format: (date: Date) => string;
        shortFormat: (date: Date) => string;
        parseValueFunction: (str?: string) => number | null;
        hasScale: boolean;
        sortValueType: string;
    };
    date: {
        cell: typeof DateCell;
        filter: typeof RangeFilter;
        format: (date: Date) => string;
        shortFormat: (date: Date) => string;
        parseValueFunction: (str?: string) => number | null;
        hasScale: boolean;
        sortValueType: string;
    };
    time: {
        cell: typeof TimeCell;
        filter: typeof RangeFilter;
        format: (date: Date) => string;
        shortFormat: (date: Date) => string;
        parseValueFunction: (str?: string) => number | null;
        hasScale: boolean;
        sortValueType: string;
    };
};
export declare const categoryColors: import("twin.macro").TwStyle[];
